@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -28,7 +23,13 @@ $form = (new CForm('GET', 'history.php'))
 	->setName('items')
 	->addItem(new CVar('action', HISTORY_BATCH_GRAPH));
 
-$table = (new CTableInfo())->addClass(ZBX_STYLE_LIST_TABLE_FIXED);
+$table = (new CTableInfo())
+	->addClass(ZBX_STYLE_LIST_TABLE_FIXED)
+	->setPageNavigation($data['paging']);
+
+if (!$data['mandatory_filter_set'] && !$data['subfilter_set']) {
+	$table->setNoDataMessage(_('Filter is not set'), _('Use the filter to display results'), ZBX_ICON_FILTER_LARGE);
+}
 
 // Latest data header.
 $col_check_all = new CColHeader(
@@ -145,12 +146,18 @@ foreach ($data['items'] as $itemid => $item) {
 			->addClass(ZBX_STYLE_CURSOR_POINTER)
 			->setHint(zbx_date2str(DATE_TIME_FORMAT_SECONDS, $last_history['clock']), '', true, '', 0);
 
-		$last_value = (new CSpan(formatHistoryValue($last_history['value'], $item, false)))
-			->addClass(ZBX_STYLE_CURSOR_POINTER)
-			->setHint(
-				(new CDiv(mb_substr($last_history['value'], 0, ZBX_HINTBOX_CONTENT_LIMIT)))->addClass(ZBX_STYLE_HINTBOX_WRAP),
-				'', true, '', 0
-			);
+		if ($item['value_type'] == ITEM_VALUE_TYPE_BINARY) {
+			$last_value = italic(_('binary value'))->addClass(ZBX_STYLE_GREY);
+		}
+		else {
+			$last_value = (new CSpan(formatHistoryValue($last_history['value'], $item, false)))
+				->addClass(ZBX_STYLE_CURSOR_POINTER)
+				->setHint(
+					(new CDiv(mb_substr($last_history['value'], 0, ZBX_HINTBOX_CONTENT_LIMIT)))
+						->addClass(ZBX_STYLE_HINTBOX_WRAP),
+					'', true, '', 0
+				);
+		}
 
 		$change = '';
 
@@ -251,7 +258,7 @@ foreach ($data['items'] as $itemid => $item) {
 		$item_key = (new CSpan($item['key_expanded']))->addClass(ZBX_STYLE_GREEN);
 
 		if (in_array($item['type'], [ITEM_TYPE_SNMPTRAP, ITEM_TYPE_TRAPPER, ITEM_TYPE_DEPENDENT])
-				|| ($item['type'] == ITEM_TYPE_ZABBIX_ACTIVE && strncmp($item['key_expanded'], 'mqtt.get', 8) === 0)) {
+				|| ($item['type'] == ITEM_TYPE_ZABBIX_ACTIVE && strncmp($item['key_expanded'], 'mqtt.get', 8) == 0)) {
 			$item_delay = '';
 		}
 		elseif ($update_interval_parser->parse($item['delay']) == CParser::PARSE_SUCCESS) {
@@ -323,17 +330,23 @@ foreach ($data['items'] as $itemid => $item) {
 }
 
 $button_list = [
-	GRAPH_TYPE_STACKED => ['name' => _('Display stacked graph'), 'attributes' => ['data-required' => 'graph']],
-	GRAPH_TYPE_NORMAL => ['name' => _('Display graph'), 'attributes' => ['data-required' => 'graph']],
-	'item.masscheck_now' => [
+	GRAPH_TYPE_STACKED => [
+		'name' => _('Display stacked graph'),
+		'attributes' => ['data-required' => 'graph', 'data-required-count' => 2]
+	],
+	GRAPH_TYPE_NORMAL => [
+		'name' => _('Display graph'),
+		'attributes' => ['data-required' => 'graph']
+	],
+	'item.execute' => [
 		'content' => (new CSimpleButton(_('Execute now')))
-			->onClick('view.massCheckNow(this);')
 			->addClass(ZBX_STYLE_BTN_ALT)
-			->addClass('no-chkbxrange')
+			->addClass('js-massexecute-item')
+			->addClass('js-no-chkbxrange')
 			->setAttribute('data-required', 'execute')
 	]
 ];
 
-$form->addItem([$table, $data['paging'], new CActionButtonList('graphtype', 'itemids', $button_list, 'latest')]);
+$form->addItem([$table, new CActionButtonList('graphtype', 'itemids', $button_list, 'latest')]);
 
 echo $form;
