@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -73,7 +68,7 @@ $('#tabs').on('tabsactivate', (event, ui) => {
 		obj = macros_elem.originalObject;
 	}
 
-	$(obj.querySelector('#tbl_macros')).dynamicRows({template: '#macro-row-tmpl'});
+	$(obj.querySelector('#tbl_macros')).dynamicRows({template: '#macro-row-tmpl', allow_empty: true});
 	$(obj.querySelector('#tbl_macros'))
 		.on('afteradd.dynamicRows', () => {
 			$('.macro-input-group', $(obj.querySelector('#tbl_macros'))).macroValue();
@@ -116,7 +111,7 @@ $('#tabs').on('tabsactivate', (event, ui) => {
 		obj = tags_elem.originalObject;
 	}
 
-	$(obj.querySelector('.tags-table')).dynamicRows({template: '#tag-row-tmpl'});
+	$(obj.querySelector('.tags-table')).dynamicRows({template: '#tag-row-tmpl', allow_empty: true});
 	$(obj.querySelector('.tags-table'))
 		.on('click', 'button.element-table-add', () => {
 			$('.tags-table .<?= ZBX_STYLE_TEXTAREA_FLEXIBLE ?>').textareaFlexible();
@@ -159,6 +154,31 @@ $('#tabs').on('tabsactivate', (event, ui) => {
 	mass_action_tpls.dispatchEvent(new CustomEvent('change', {}));
 })();
 
+// Monitored by.
+(() => {
+	const element = document.querySelector('#monitored-by-field');
+
+	if (element === null) {
+		return false;
+	}
+
+	const obj = element.tagName === 'SPAN' ? element.originalObject : element;
+	const monitored_by = obj.querySelector('#monitored_by');
+
+	if (monitored_by === null) {
+		return false;
+	}
+
+	monitored_by.addEventListener('change', (e) => {
+		obj.querySelector('.js-field-proxy').style.display =
+			e.target.value == <?= ZBX_MONITORED_BY_PROXY ?> ? '' : 'none';
+		obj.querySelector('.js-field-proxy-group').style.display =
+			e.target.value == <?= ZBX_MONITORED_BY_PROXY_GROUP ?> ? '' : 'none';
+	});
+
+	monitored_by.dispatchEvent(new CustomEvent('change', {}));
+})();
+
 // Inventory mode.
 (() => {
 	const inventory = document.querySelector('#inventoryFormList');
@@ -306,12 +326,13 @@ $('#tabs').on('tabsactivate', (event, ui) => {
 	obj.querySelectorAll('[name=valuemap_massupdate]').forEach((elem) => elem.addEventListener('click',
 		(event) => toggleVisible(obj, event.currentTarget.value)
 	));
-	obj.querySelectorAll('.element-table-addfrom').forEach(elm => elm.addEventListener('click',
+	obj.querySelectorAll('.js-element-table-addfrom').forEach(elm => elm.addEventListener('click',
 		(event) => openAddfromPopup(event.target)
 	));
 
 	$('#valuemap-rename-table').dynamicRows({
 		template: '#valuemap-rename-row-tmpl',
+		allow_empty: true,
 		row: '.form_row',
 		rows: [{from: '', to: ''}]
 	});
@@ -458,6 +479,11 @@ function submitPopup(overlay) {
 
 			message_box.insertBefore(form);
 		}
+		else if (action === 'item.prototype.massupdate' || action === 'item.massupdate') {
+			// Item and item prototype lists javascript handles successful update.
+			overlayDialogueDestroy(overlay.dialogueid);
+			overlay.$dialogue[0].dispatchEvent(new CustomEvent('dialogue.submit', {detail: response}));
+		}
 		else {
 			postMessageOk(response.title);
 
