@@ -62,6 +62,7 @@ $fields = [
 	'cancel' =>				[T_ZBX_STR, O_OPT, P_SYS,		null,			null],
 	'form' =>				[T_ZBX_STR, O_OPT, P_SYS,		null,			null],
 	'form_refresh' =>		[T_ZBX_INT, O_OPT, P_SYS,		null,			null],
+	'backurl' =>			[T_ZBX_STR, O_OPT, null,		null,			null],
 	// filter
 	'filter_set' =>			[T_ZBX_STR, O_OPT, P_SYS,			null,	null],
 	'filter_rst' =>			[T_ZBX_STR, O_OPT, P_SYS,			null,	null],
@@ -144,6 +145,11 @@ elseif ($hostid && !isWritableHostTemplates([$hostid])) {
 	access_deny();
 }
 
+// Validate backurl.
+if (hasRequest('backurl') && !CHtmlUrlValidator::validateSameSite(getRequest('backurl'))) {
+	access_deny();
+}
+
 /*
  * Actions
  */
@@ -286,7 +292,17 @@ elseif (getRequest('graphid', '') && getRequest('action', '') === 'graph.updated
 		'discover' => getRequest('discover', DB::getDefault('graphs', 'discover'))
 	]);
 
-	show_messages($result, _('Graph prototype updated'), _('Cannot update graph prototype'));
+	if ($result) {
+		CMessageHelper::setSuccessTitle(_('Graph prototype updated'));
+	}
+	else {
+		CMessageHelper::setErrorTitle(_('Cannot update graph prototype'));
+	}
+
+	if (hasRequest('backurl')) {
+		$response = new CControllerResponseRedirect(getRequest('backurl'));
+		$response->redirect();
+	}
 }
 elseif (hasRequest('action') && getRequest('action') === 'graph.massdelete' && hasRequest('group_graphid')) {
 	$graphIds = getRequest('group_graphid');
@@ -655,6 +671,16 @@ else {
 		? API::GraphPrototype()->get($options)
 		: API::Graph()->get($options);
 
+	if ($data['context'] === 'host') {
+		$editable_hosts = API::Host()->get([
+			'output' => ['hostids'],
+			'graphids' => array_column($data['graphs'], 'graphid'),
+			'editable' => true
+		]);
+
+		$data['editable_hosts'] = array_column($editable_hosts, 'hostid');
+	}
+
 	if ($sort_field === 'graphtype') {
 		foreach ($data['graphs'] as $gnum => $graph) {
 			$data['graphs'][$gnum]['graphtype'] = graphType($graph['graphtype']);
@@ -690,7 +716,6 @@ else {
 		'selectDiscoveryRule' => ['itemid', 'name'],
 		'selectGraphDiscovery'	=> ['status', 'ts_delete'],
 		'selectHosts' => ($data['hostid'] == 0) ? ['name'] : null,
-		'selectTemplates' => ($data['hostid'] == 0) ? ['name'] : null,
 		'graphids' => zbx_objectValues($data['graphs'], 'graphid'),
 		'preservekeys' => true
 	];
@@ -739,6 +764,13 @@ else {
 
 	order_result($data['graphs'], $sort_field, $sort_order);
 
+	if ($data['hostid'] == 0) {
+		foreach ($data['graphs'] as &$graph) {
+			CArrayHelper::sort($graph['hosts'], ['name']);
+		}
+		unset($graph);
+	}
+
 	$data['parent_templates'] = getGraphParentTemplates($data['graphs'], ($data['parent_discoveryid'] === null)
 		? ZBX_FLAG_DISCOVERY_NORMAL
 		: ZBX_FLAG_DISCOVERY_PROTOTYPE
