@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -39,6 +34,10 @@ class CHostGroup extends CApiService {
 	protected $tableAlias = 'g';
 	protected $sortColumns = ['groupid', 'name'];
 
+	public const OUTPUT_FIELDS = ['groupid', 'name', 'flags', 'uuid'];
+
+	private const GROUP_DISCOVERY_FIELDS = ['parent_group_prototypeid', 'name', 'lastcheck', 'ts_delete', 'status'];
+
 	/**
 	 * Get host groups.
 	 *
@@ -49,13 +48,11 @@ class CHostGroup extends CApiService {
 	public function get(array $options) {
 		$result = [];
 
-		$output_fields = ['groupid', 'name', 'flags', 'uuid'];
-		$host_fields = ['hostid', 'host', 'name', 'description', 'proxy_hostid', 'status', 'ipmi_authtype',
+		$host_fields = ['hostid', 'host', 'name', 'description', 'proxyid', 'status', 'ipmi_authtype',
 			'ipmi_privilege', 'ipmi_password', 'ipmi_username', 'inventory_mode', 'tls_connect', 'tls_accept',
 			'tls_psk_identity', 'tls_psk', 'tls_issuer', 'tls_subject', 'maintenanceid', 'maintenance_type',
 			'maintenance_from', 'maintenance_status', 'flags'
 		];
-		$group_discovery_fields = ['groupid', 'lastcheck', 'name', 'parent_group_prototypeid', 'ts_delete'];
 		$discovery_rule_fields = ['itemid', 'hostid', 'name', 'type', 'key_', 'url', 'query_fields', 'request_method',
 			'timeout', 'post_type', 'posts', 'headers', 'status_codes', 'follow_redirects', 'retrieve_mode',
 			'http_proxy', 'authtype', 'verify_peer', 'verify_host', 'ssl_cert_file', 'ssl_key_file', 'ssl_key_password',
@@ -96,11 +93,11 @@ class CHostGroup extends CApiService {
 			'excludeSearch' =>						['type' => API_BOOLEAN, 'default' => false],
 			'searchWildcardsEnabled' =>				['type' => API_BOOLEAN, 'default' => false],
 			// output
-			'output' =>								['type' => API_OUTPUT, 'in' => implode(',', $output_fields), 'default' => API_OUTPUT_EXTEND],
+			'output' =>								['type' => API_OUTPUT, 'in' => implode(',', self::OUTPUT_FIELDS), 'default' => API_OUTPUT_EXTEND],
 			'selectHosts' =>						['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL | API_ALLOW_COUNT, 'in' => implode(',', $host_fields), 'default' => null],
-			'selectGroupDiscovery' =>				['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', $group_discovery_fields), 'default' => null],
-			'selectDiscoveryRule' =>				['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', $discovery_rule_fields), 'default' => null],
-			'selectHostPrototype' =>				['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', $host_prototype_fields), 'default' => null],
+			'selectGroupDiscoveries' =>				['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', self::GROUP_DISCOVERY_FIELDS), 'default' => null],
+			'selectDiscoveryRules' =>				['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', $discovery_rule_fields), 'default' => null],
+			'selectHostPrototypes' =>				['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', $host_prototype_fields), 'default' => null],
 			'countOutput' =>						['type' => API_BOOLEAN, 'default' => false],
 			// sort and limit
 			'sortfield' =>							['type' => API_STRINGS_UTF8, 'flags' => API_NORMALIZE, 'in' => implode(',', $this->sortColumns), 'uniq' => true, 'default' => []],
@@ -125,7 +122,7 @@ class CHostGroup extends CApiService {
 		];
 
 		if (!$options['countOutput'] && $options['output'] === API_OUTPUT_EXTEND) {
-			$options['output'] = $output_fields;
+			$options['output'] = self::OUTPUT_FIELDS;
 		}
 
 		// editable + PERMISSION CHECK
@@ -438,7 +435,7 @@ class CHostGroup extends CApiService {
 	public function delete(array $groupids): array {
 		$this->validateDelete($groupids, $db_groups);
 
-		self::deleteForce($db_groups);
+		$this->deleteForce($db_groups);
 
 		return ['groupids' => $groupids];
 	}
@@ -446,7 +443,9 @@ class CHostGroup extends CApiService {
 	/**
 	 * @param array $db_groups
 	 */
-	public static function deleteForce(array $db_groups): void {
+	public function deleteForce(array $db_groups): void {
+		self::validateDeleteForce($db_groups);
+
 		$groupids = array_keys($db_groups);
 
 		// delete sysmap element
@@ -458,7 +457,7 @@ class CHostGroup extends CApiService {
 		$db_actions = DBselect(
 			'SELECT DISTINCT c.actionid'.
 			' FROM conditions c'.
-			' WHERE c.conditiontype='.CONDITION_TYPE_HOST_GROUP.
+			' WHERE c.conditiontype='.ZBX_CONDITION_TYPE_HOST_GROUP.
 				' AND '.dbConditionString('c.value', $groupids)
 		);
 		while ($db_action = DBfetch($db_actions)) {
@@ -490,7 +489,7 @@ class CHostGroup extends CApiService {
 
 		// delete action conditions
 		DB::delete('conditions', [
-			'conditiontype' => CONDITION_TYPE_HOST_GROUP,
+			'conditiontype' => ZBX_CONDITION_TYPE_HOST_GROUP,
 			'value' => $groupids
 		]);
 
@@ -536,16 +535,29 @@ class CHostGroup extends CApiService {
 
 		DB::delete('operations', ['operationid' => $del_operationids]);
 
+		$this->unlinkHosts($db_groups);
+
 		DB::delete('hstgrp', ['groupid' => $groupids]);
 
 		self::addAuditLog(CAudit::ACTION_DELETE, CAudit::RESOURCE_HOST_GROUP, $db_groups);
 	}
 
+	private function unlinkHosts(array $db_groups): void {
+		$data = [
+			'groups' => [],
+			'hosts' => []
+		];
+
+		foreach ($db_groups as $db_group) {
+			$data['groups'][] = ['groupid' => $db_group['groupid']];
+		}
+
+		$this->massUpdate($data);
+	}
+
 	/**
 	 * @param array $groups
 	 *
-	 * @static
-	 *
 	 * @throws APIException if the input is invalid.
 	 */
 	private static function validateCreate(array &$groups): void {
@@ -558,8 +570,10 @@ class CHostGroup extends CApiService {
 			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
+		self::addUuid($groups);
+
+		self::checkUuidDuplicates($groups);
 		self::checkDuplicates($groups);
-		self::checkAndAddUuid($groups);
 	}
 
 	/**
@@ -571,7 +585,7 @@ class CHostGroup extends CApiService {
 	 * @throws APIException if the input is invalid.
 	 */
 	protected function validateUpdate(array &$groups, array &$db_groups = null): void {
-		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['groupid'], ['name']], 'fields' => [
+		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['uuid'], ['groupid'], ['name']], 'fields' => [
 			'uuid' => 		['type' => API_UUID],
 			'groupid' =>	['type' => API_ID, 'flags' => API_REQUIRED],
 			'name' =>		['type' => API_HG_NAME, 'length' => DB::getFieldLength('hstgrp', 'name')]
@@ -582,7 +596,7 @@ class CHostGroup extends CApiService {
 		}
 
 		$db_groups = $this->get([
-			'output' => ['groupid', 'name', 'flags'],
+			'output' => ['uuid', 'groupid', 'name', 'flags'],
 			'groupids' => array_column($groups, 'groupid'),
 			'editable' => true,
 			'preservekeys' => true
@@ -593,6 +607,7 @@ class CHostGroup extends CApiService {
 		}
 
 		self::checkGroupsNotDiscovered($db_groups);
+		self::checkUuidDuplicates($groups, $db_groups);
 		self::checkDuplicates($groups, $db_groups);
 	}
 
@@ -646,8 +661,6 @@ class CHostGroup extends CApiService {
 				)
 			);
 		}
-
-		self::validateDeleteForce($db_groups);
 	}
 
 	/**
@@ -655,20 +668,9 @@ class CHostGroup extends CApiService {
 	 *
 	 * @throws APIException if unable to delete groups.
 	 */
-	public static function validateDeleteForce(array $db_groups): void {
+	private static function validateDeleteForce(array $db_groups): void {
 		$groupids = array_keys($db_groups);
 
-		$db_hosts = API::Host()->get([
-			'output' => ['host'],
-			'groupids' => $groupids,
-			'nopermissions' => true,
-			'preservekeys' => true
-		]);
-
-		if ($db_hosts) {
-			self::checkHostsWithoutGroups($db_hosts, $groupids);
-		}
-
 		$db_scripts = DB::select('scripts', [
 			'output' => ['groupid'],
 			'filter' => ['groupid' => $groupids],
@@ -703,8 +705,6 @@ class CHostGroup extends CApiService {
 	/**
 	 * Check for unique host group names.
 	 *
-	 * @static
-	 *
 	 * @param array      $groups
 	 * @param array|null $db_groups
 	 *
@@ -739,31 +739,58 @@ class CHostGroup extends CApiService {
 	}
 
 	/**
-	 * Check that new UUIDs are not already used and generate UUIDs where missing.
+	 * Add the UUID to those of the given host groups that don't have the 'uuid' parameter set.
 	 *
-	 * @static
-	 *
-	 * @param array $groups_to_create
-	 *
-	 * @throws APIException
+	 * @param array $groups
 	 */
-	private static function checkAndAddUuid(array &$groups_to_create): void {
-		foreach ($groups_to_create as &$group) {
+	private static function addUuid(array &$groups): void {
+		foreach ($groups as &$group) {
 			if (!array_key_exists('uuid', $group)) {
 				$group['uuid'] = generateUuidV4();
 			}
 		}
 		unset($group);
+	}
 
-		$db_uuid = DB::select('hstgrp', [
+	/**
+	 * Verify host group UUIDs are not repeated.
+	 *
+	 * @param array      $groups
+	 * @param array|null $db_groups
+	 *
+	 * @throws APIException
+	 */
+	private static function checkUuidDuplicates(array $groups, array $db_groups = null): void {
+		$group_indexes = [];
+
+		foreach ($groups as $i => $group) {
+			if (!array_key_exists('uuid', $group)) {
+				continue;
+			}
+
+			if ($db_groups === null || $group['uuid'] !== $db_groups[$group['groupid']]['uuid']) {
+				$group_indexes[$group['uuid']] = $i;
+			}
+		}
+
+		if (!$group_indexes) {
+			return;
+		}
+
+		$duplicates = DB::select('hstgrp', [
 			'output' => ['uuid'],
-			'filter' => ['uuid' => array_column($groups_to_create, 'uuid'), 'type' => HOST_GROUP_TYPE_HOST_GROUP],
+			'filter' => [
+				'type' => HOST_GROUP_TYPE_HOST_GROUP,
+				'uuid' => array_keys($group_indexes)
+			],
 			'limit' => 1
 		]);
 
-		if ($db_uuid) {
+		if ($duplicates) {
 			self::exception(ZBX_API_ERROR_PARAMETERS,
-				_s('Entry with UUID "%1$s" already exists.', $db_uuid[0]['uuid'])
+				_s('Invalid parameter "%1$s": %2$s.', '/'.($group_indexes[$duplicates[0]['uuid']] + 1),
+					_('host group with the same UUID already exists')
+				)
 			);
 		}
 	}
@@ -771,8 +798,6 @@ class CHostGroup extends CApiService {
 	/**
 	 * Check whether no one of passed groups are discovered host.
 	 *
-	 * @static
-	 *
 	 * @param array  $db_groups
 	 * @param string $db_groups[][name]
 	 * @param int    $db_groups[][flags]
@@ -911,8 +936,6 @@ class CHostGroup extends CApiService {
 	/**
 	 * Prepare rights to inherit from parent host groups.
 	 *
-	 * @static
-	 *
 	 * @param array  $group_links
 	 * @param array  $usrgrps
 	 * @param array  $db_usrgrps
@@ -950,8 +973,6 @@ class CHostGroup extends CApiService {
 	/**
 	 * Prepare tag filters to inherit from parent host groups.
 	 *
-	 * @static
-	 *
 	 * @param array  $group_links
 	 * @param array  $usrgrps
 	 * @param array  $db_usrgrps
@@ -996,78 +1017,14 @@ class CHostGroup extends CApiService {
 	 * @return array
 	 */
 	public function massAdd(array $data): array {
-		$this->validateMassAdd($data, $db_groups);
+		$this->validateMassAdd($data);
 
-		$groups = self::getGroupsByData($data, $db_groups);
-		$ins_hosts_groups = self::getInsHostsGroups($groups, __FUNCTION__);
-
-		if ($ins_hosts_groups) {
-			$hostgroupids = DB::insertBatch('hosts_groups', $ins_hosts_groups);
-			self::addHostgroupids($groups, $hostgroupids);
-		}
-
-		self::addAuditLog(CAudit::ACTION_UPDATE, CAudit::RESOURCE_HOST_GROUP, $groups, $db_groups);
+		API::Host()->massAdd($data);
 
 		return ['groupids' => array_column($data['groups'], 'groupid')];
 	}
 
-	/**
-	 * Replace hosts on the given host groups.
-	 *
-	 * @param array $data
-	 *
-	 * @return array
-	 */
-	public function massUpdate(array $data): array {
-		$this->validateMassUpdate($data, $db_groups);
-
-		$groups = self::getGroupsByData($data, $db_groups);
-		$ins_hosts_groups = self::getInsHostsGroups($groups, __FUNCTION__, $db_hostgroupids);
-		$del_hostgroupids = self::getDelHostgroupids($db_groups, $db_hostgroupids);
-
-		if ($ins_hosts_groups) {
-			$hostgroupids = DB::insertBatch('hosts_groups', $ins_hosts_groups);
-			self::addHostgroupids($groups, $hostgroupids);
-		}
-
-		if ($del_hostgroupids) {
-			DB::delete('hosts_groups', ['hostgroupid' => $del_hostgroupids]);
-		}
-
-		self::addAuditLog(CAudit::ACTION_UPDATE, CAudit::RESOURCE_HOST_GROUP, $groups, $db_groups);
-
-		return ['groupids' => array_column($data['groups'], 'groupid')];
-	}
-
-	/**
-	 * Remove given hosts from given host groups.
-	 *
-	 * @param array $data
-	 *
-	 * @return array
-	 */
-	public function massRemove(array $data): array {
-		$this->validateMassRemove($data, $db_groups);
-
-		$groups = self::getGroupsByData([], $db_groups);
-		$del_hostgroupids = self::getDelHostgroupids($db_groups);
-
-		if ($del_hostgroupids) {
-			DB::delete('hosts_groups', ['hostgroupid' => $del_hostgroupids]);
-		}
-
-		self::addAuditLog(CAudit::ACTION_UPDATE, CAudit::RESOURCE_HOST_GROUP, $groups, $db_groups);
-
-		return ['groupids' => $data['groupids']];
-	}
-
-	/**
-	 * @param array      $data
-	 * @param array|null $db_groups
-	 *
-	 * @throws APIException if the input is invalid.
-	 */
-	private function validateMassAdd(array &$data, ?array &$db_groups): void {
+	private function validateMassAdd(array &$data): void {
 		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
 			'groups' =>		['type' => API_OBJECTS, 'flags' => API_REQUIRED | API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['groupid']], 'fields' => [
 				'groupid' =>	['type' => API_ID, 'flags' => API_REQUIRED]
@@ -1080,43 +1037,24 @@ class CHostGroup extends CApiService {
 		if (!CApiInputValidator::validate($api_input_rules, $data, '/', $error)) {
 			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
-
-		$db_groups = $this->get([
-			'output' => ['groupid','name'],
-			'groupids' => array_column($data['groups'], 'groupid'),
-			'editable' => true,
-			'preservekeys' => true
-		]);
-
-		if (count($db_groups) != count($data['groups'])) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS, _('No permissions to referred object or it does not exist!'));
-		}
-
-		$hostids = array_column($data['hosts'], 'hostid');
-
-		$db_hosts = API::Host()->get([
-			'output' => ['host', 'flags'],
-			'hostids' => $hostids,
-			'editable' => true
-		]);
-
-		if (count($db_hosts) != count($hostids)) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS, _('No permissions to referred object or it does not exist!'));
-		}
-
-		self::checkHostsNotDiscovered($db_hosts);
-		self::addAffectedObjects($hostids, $db_groups);
 	}
 
 	/**
-	 * Validation of massUpdate input fields.
+	 * Replace hosts on the given host groups.
 	 *
-	 * @param array      $data       [IN/OUT]
-	 * @param array|null $db_groups  [OUT]
+	 * @param array $data
 	 *
-	 * @throws APIException if the input is invalid.
+	 * @return array
 	 */
-	private function validateMassUpdate(array &$data, ?array &$db_groups): void {
+	public function massUpdate(array $data): array {
+		$this->validateMassUpdate($data, $hosts, $db_hosts);
+
+		API::Host()->updateForce($hosts, $db_hosts);
+
+		return ['groupids' => array_column($data['groups'], 'groupid')];
+	}
+
+	private function validateMassUpdate(array &$data, ?array &$hosts, ?array &$db_hosts): void {
 		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
 			'groups' =>		['type' => API_OBJECTS, 'flags' => API_REQUIRED | API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['groupid']], 'fields' => [
 				'groupid' =>	['type' => API_ID, 'flags' => API_REQUIRED]
@@ -1130,55 +1068,108 @@ class CHostGroup extends CApiService {
 			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
-		$groupids = array_column($data['groups'], 'groupid');
-
 		$db_groups = $this->get([
-			'output' => ['groupid', 'name'],
-			'groupids' => $groupids,
+			'output' => [],
+			'groupids' => array_column($data['groups'], 'groupid'),
 			'editable' => true,
 			'preservekeys' => true
 		]);
 
-		if (count($db_groups) != count($groupids)) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS, _('No permissions to referred object or it does not exist!'));
+		foreach ($data['groups'] as $i => $group) {
+			if (!array_key_exists($group['groupid'], $db_groups)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS, _s('Invalid parameter "%1$s": %2$s.',
+					'/groups/'.($i + 1), _('object does not exist, or you have no permissions to it')
+				));
+			}
+		}
+
+		$db_hosts = API::Host()->get([
+			'output' => ['hostid', 'host', 'flags'],
+			'groupids' => array_column($data['groups'], 'groupid'),
+			'editable' => true,
+			'preservekeys' => true
+		]);
+
+		if ($data['hosts']) {
+			$db_hosts += API::Host()->get([
+				'output' => ['hostid', 'host', 'flags'],
+				'hostids' => array_column($data['hosts'], 'hostid'),
+				'editable' => true,
+				'preservekeys' => true
+			]);
+		}
+
+		foreach ($data['hosts'] as $i => $host) {
+			if (!array_key_exists($host['hostid'], $db_hosts)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS, _s('Invalid parameter "%1$s": %2$s.',
+					'/hosts/'.($i + 1), _('object does not exist, or you have no permissions to it')
+				));
+			}
+			elseif ($db_hosts[$host['hostid']]['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, _s('Invalid parameter "%1$s": %2$s.',
+					'/hosts/'.($i + 1),
+					_s('cannot update readonly parameter "%1$s" of discovered object', 'groups')
+				));
+			}
+		}
+
+		$hosts = [];
+		$del_hosts = [];
+
+		if (!$db_hosts) {
+			return;
 		}
 
 		$hostids = array_column($data['hosts'], 'hostid');
 
-		if ($hostids) {
-			$db_hosts = API::Host()->get([
-				'output' => ['host', 'flags'],
-				'hostids' => $hostids,
-				'editable' => true
-			]);
-
-			if (count($db_hosts) != count($hostids)) {
-				self::exception(ZBX_API_ERROR_PERMISSIONS,
-					_('No permissions to referred object or it does not exist!')
-				);
+		foreach ($db_hosts as $db_host) {
+			if (in_array($db_host['hostid'], $hostids)) {
+				$hosts[$db_host['hostid']] = [
+					'hostid' => $db_host['hostid'],
+					'groups' => $data['groups']
+				];
+			}
+			else {
+				$del_hosts[$db_host['hostid']] = [
+					'hostid' => $db_host['hostid'],
+					'groups' => []
+				];
 			}
-
-			self::checkHostsNotDiscovered($db_hosts);
 		}
 
-		self::addAffectedObjects([], $db_groups, $db_hostids);
+		API::Host()->addAffectedGroups($hosts + $del_hosts, $db_hosts);
 
-		$del_hostids = array_diff($db_hostids, $hostids);
-
-		if ($del_hostids) {
-			self::checkDeletedHosts($del_hostids, $groupids);
+		if ($hosts) {
+			API::Host()->addUnchangedGroups($hosts, $db_hosts);
 		}
+
+		if ($del_hosts) {
+			API::Host()->addUnchangedGroups($del_hosts, $db_hosts,
+				['groupids' => array_column($data['groups'], 'groupid')]
+			);
+		}
+
+		$hosts += $del_hosts;
+
+		API::Host()->checkHostsWithoutGroups($hosts, $db_hosts);
 	}
 
 	/**
-	 * Validation of massRemove input fields.
+	 * Remove given hosts from given host groups.
 	 *
-	 * @param array      $data       [IN/OUT]
-	 * @param array|null $db_groups  [OUT]
+	 * @param array $data
 	 *
-	 * @throws APIException if the input is invalid.
+	 * @return array
 	 */
-	private function validateMassRemove(array &$data, ?array &$db_groups): void {
+	public function massRemove(array $data): array {
+		$this->validateMassRemove($data);
+
+		API::Host()->massRemove($data);
+
+		return ['groupids' => $data['groupids']];
+	}
+
+	private function validateMassRemove(array &$data): void {
 		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
 			'groupids' =>	['type' => API_IDS, 'flags' => API_REQUIRED | API_NOT_EMPTY | API_NORMALIZE, 'uniq' => true],
 			'hostids' =>	['type' => API_IDS, 'flags' => API_REQUIRED | API_NOT_EMPTY | API_NORMALIZE, 'uniq' => true]
@@ -1187,285 +1178,13 @@ class CHostGroup extends CApiService {
 		if (!CApiInputValidator::validate($api_input_rules, $data, '/', $error)) {
 			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
-
-		$db_groups = $this->get([
-			'output' => ['groupid', 'name'],
-			'groupids' => $data['groupids'],
-			'editable' => true,
-			'preservekeys' => true
-		]);
-
-		if (count($db_groups) != count($data['groupids'])) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS, _('No permissions to referred object or it does not exist!'));
-		}
-
-		$db_hosts = API::Host()->get([
-			'output' => ['host', 'flags'],
-			'hostids' => $data['hostids'],
-			'editable' => true,
-			'preservekeys' => true
-		]);
-
-		if (count($db_hosts) != count($data['hostids'])) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS, _('No permissions to referred object or it does not exist!'));
-		}
-
-		self::checkHostsNotDiscovered($db_hosts);
-		self::checkHostsWithoutGroups($db_hosts, $data['groupids']);
-
-		self::addAffectedObjects($data['hostids'], $db_groups);
-	}
-
-	/**
-	 * Check whether no one of given hosts are discovered host.
-	 *
-	 * @static
-	 *
-	 * @param array  $db_hosts
-	 * @param string $db_hosts[][host]
-	 * @param int    $db_hosts[][flags]
-	 *
-	 * @throws APIException
-	 */
-	private static function checkHostsNotDiscovered(array $db_hosts): void {
-		foreach ($db_hosts as $db_host) {
-			if ($db_host['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
-				self::exception(ZBX_API_ERROR_PARAMETERS,
-					_s('Cannot update groups for discovered host "%1$s".', $db_host['host'])
-				);
-			}
-		}
-	}
-
-	/**
-	 * Check to exclude an opportunity to leave host without groups.
-	 *
-	 * @static
-	 *
-	 * @param array  $db_hosts
-	 * @param string $db_hosts[<hostid>]['host']
-	 * @param array  $groupids
-	 *
-	 * @throws APIException
-	 */
-	public static function checkHostsWithoutGroups(array $db_hosts, array $groupids): void {
-		$hostids = array_keys($db_hosts);
-
-		$hostids_with_groups = DBfetchColumn(DBselect(
-			'SELECT DISTINCT hg.hostid'.
-			' FROM hosts_groups hg'.
-			' WHERE '.dbConditionInt('hg.groupid', $groupids, true).
-				' AND '.dbConditionInt('hg.hostid', $hostids)
-		), 'hostid');
-
-		$hostids_without_groups = array_diff($hostids, $hostids_with_groups);
-
-		if ($hostids_without_groups) {
-			$hostid = reset($hostids_without_groups);
-			$error = _s('Host "%1$s" cannot be without host group.', $db_hosts[$hostid]['host']);
-
-			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
-		}
-	}
-
-	/**
-	 * Add the existing hosts whether these are affected by the mass methods.
-	 * If host IDs passed as empty array, all host links of given groups will be collected from database and all
-	 * existing host IDs will be collected in $db_hostids.
-	 *
-	 * @static
-	 *
-	 * @param array      $hostids
-	 * @param array      $db_groups
-	 * @param array|null $db_hostids
-	 */
-	private static function addAffectedObjects(array $hostids, array &$db_groups, array &$db_hostids = null): void {
-		if (!$hostids) {
-			$db_hostids = [];
-		}
-
-		foreach ($db_groups as &$db_group) {
-			$db_group['hosts'] = [];
-		}
-		unset($db_group);
-
-		if ($hostids) {
-			$options = [
-				'output' => ['hostgroupid', 'hostid', 'groupid'],
-				'filter' => [
-					'hostid' => $hostids,
-					'groupid' => array_keys($db_groups)
-				]
-			];
-			$db_hosts_groups = DBselect(DB::makeSql('hosts_groups', $options));
-		}
-		else {
-			$db_hosts_groups = DBselect(
-				'SELECT hg.hostgroupid,hg.hostid,hg.groupid'.
-				' FROM hosts_groups hg,hosts h'.
-				' WHERE hg.hostid=h.hostid'.
-					' AND '.dbConditionInt('hg.groupid', array_keys($db_groups)).
-					' AND h.flags='.ZBX_FLAG_DISCOVERY_NORMAL
-			);
-		}
-
-		while ($link = DBfetch($db_hosts_groups)) {
-			$db_groups[$link['groupid']]['hosts'][$link['hostgroupid']] = [
-				'hostgroupid' => $link['hostgroupid'],
-				'hostid' => $link['hostid']
-			];
-
-			if (!$hostids) {
-				$db_hostids[$link['hostid']] = true;
-			}
-		}
-
-		if (!$hostids) {
-			$db_hostids = array_keys($db_hostids);
-		}
-	}
-
-	/**
-	 * Check to delete given hosts from the given host groups.
-	 *
-	 * @static
-	 *
-	 * @param array $del_hostids
-	 * @param array $groupids
-	 *
-	 * @throws APIException
-	 */
-	private static function checkDeletedHosts(array $del_hostids, array $groupids): void {
-		$db_hosts = API::Host()->get([
-			'output' => ['host'],
-			'hostids' => $del_hostids,
-			'editable' => true,
-			'preservekeys' => true
-		]);
-
-		if (count($db_hosts) != count($del_hostids)) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS, _('No permissions to referred object or it does not exist!'));
-		}
-
-		self::checkHostsWithoutGroups($db_hosts, $groupids);
-	}
-
-	/**
-	 * Get host groups input array based on requested data and database data.
-	 *
-	 * @static
-	 *
-	 * @param array $data
-	 * @param array $db_groups
-	 *
-	 * @return array
-	 */
-	private static function getGroupsByData(array $data, array $db_groups): array {
-		$groups = [];
-
-		foreach ($db_groups as $db_group) {
-			$group = ['groupid' => $db_group['groupid']];
-
-			$group['hosts'] = [];
-			$db_hosts = array_column($db_group['hosts'], null, 'hostid');
-
-			if (array_key_exists('hosts', $data)) {
-				foreach ($data['hosts'] as $host) {
-					if (array_key_exists($host['hostid'], $db_hosts)) {
-						$group['hosts'][] = $db_hosts[$host['hostid']];
-					}
-					else {
-						$group['hosts'][] = ['hostid' => $host['hostid']];
-					}
-				}
-			}
-
-			$groups[] = $group;
-		}
-
-		return $groups;
-	}
-
-	/**
-	 * Get rows to insert hosts on the given host groups.
-	 *
-	 * @static
-	 *
-	 * @param array      $groups
-	 * @param string     $method
-	 * @param array|null $db_hostgroupids
-	 *
-	 * @return array
-	 */
-	private static function getInsHostsGroups(array $groups, string $method, array &$db_hostgroupids = null): array {
-		$ins_hosts_groups = [];
-
-		if ($method === 'massUpdate') {
-			$db_hostgroupids = [];
-		}
-
-		foreach ($groups as $group) {
-			foreach ($group['hosts'] as $host) {
-				if (!array_key_exists('hostgroupid', $host)) {
-					$ins_hosts_groups[] = [
-						'hostid' => $host['hostid'],
-						'groupid' => $group['groupid']
-					];
-				}
-				elseif ($method === 'massUpdate') {
-					$db_hostgroupids[$host['hostgroupid']] = true;
-				}
-			}
-		}
-
-		return $ins_hosts_groups;
-	}
-
-	/**
-	 * Add IDs of inserted hosts on the given host groups.
-	 *
-	 * @param array $groups
-	 * @param array $hostgroupids
-	 */
-	private static function addHostgroupids(array &$groups, array $hostgroupids): void {
-		foreach ($groups as &$group) {
-			foreach ($group['hosts'] as &$host) {
-				if (!array_key_exists('hostgroupid', $host)) {
-					$host['hostgroupid'] = array_shift($hostgroupids);
-				}
-			}
-			unset($host);
-		}
-		unset($group);
-	}
-
-	/**
-	 * Get IDs to delete hosts from the given host groups.
-	 *
-	 * @static
-	 *
-	 * @param array $db_groups
-	 * @param array $db_hostgroupids
-	 *
-	 * @return array
-	 */
-	private static function getDelHostgroupids(array $db_groups, array $db_hostgroupids = []): array {
-		$del_hostgroupids = [];
-
-		foreach ($db_groups as $db_group) {
-			$del_hostgroupids += array_diff_key($db_group['hosts'], $db_hostgroupids);
-		}
-
-		$del_hostgroupids = array_keys($del_hostgroupids);
-
-		return $del_hostgroupids;
 	}
 
 	protected function addRelatedObjects(array $options, array $result): array {
 		$result = parent::addRelatedObjects($options, $result);
 
-		$groupIds = array_keys($result);
-		sort($groupIds);
+		$groupids = array_keys($result);
+		sort($groupids);
 
 		// adding hosts
 		if ($options['selectHosts'] !== null) {
@@ -1489,7 +1208,7 @@ class CHostGroup extends CApiService {
 			}
 			else {
 				$hosts = API::Host()->get([
-					'groupids' => $groupIds,
+					'groupids' => $groupids,
 					'countOutput' => true,
 					'groupCount' => true
 				]);
@@ -1503,65 +1222,69 @@ class CHostGroup extends CApiService {
 		}
 
 		// adding discovery rule
-		if ($options['selectDiscoveryRule'] !== null && $options['selectDiscoveryRule'] != API_OUTPUT_COUNT) {
+		if ($options['selectDiscoveryRules'] !== null) {
 			// discovered items
-			$discoveryRules = DBFetchArray(DBselect(
+			$discovery_rules = DBFetchArray(DBselect(
 				'SELECT gd.groupid,hd.parent_itemid'.
 					' FROM group_discovery gd,group_prototype gp,host_discovery hd'.
-					' WHERE '.dbConditionInt('gd.groupid', $groupIds).
+					' WHERE '.dbConditionInt('gd.groupid', $groupids).
 					' AND gd.parent_group_prototypeid=gp.group_prototypeid'.
 					' AND gp.hostid=hd.hostid'
 			));
-			$relationMap = $this->createRelationMap($discoveryRules, 'groupid', 'parent_itemid');
+			$relation_map = $this->createRelationMap($discovery_rules, 'groupid', 'parent_itemid');
 
-			$discoveryRules = API::DiscoveryRule()->get([
-				'output' => $options['selectDiscoveryRule'],
-				'itemids' => $relationMap->getRelatedIds(),
+			$discovery_rules = API::DiscoveryRule()->get([
+				'output' => $options['selectDiscoveryRules'],
+				'itemids' => $relation_map->getRelatedIds(),
 				'preservekeys' => true
 			]);
-			$result = $relationMap->mapOne($result, $discoveryRules, 'discoveryRule');
+
+			$result = $relation_map->mapMany($result, $discovery_rules, 'discoveryRules');
 		}
 
 		// adding host prototype
-		if ($options['selectHostPrototype'] !== null) {
+		if ($options['selectHostPrototypes'] !== null) {
 			$db_links = DBFetchArray(DBselect(
 				'SELECT gd.groupid,gp.hostid'.
 					' FROM group_discovery gd,group_prototype gp'.
-					' WHERE '.dbConditionInt('gd.groupid', $groupIds).
+					' WHERE '.dbConditionInt('gd.groupid', $groupids).
 					' AND gd.parent_group_prototypeid=gp.group_prototypeid'
 			));
 
 			$host_prototypes = API::HostPrototype()->get([
-				'output' => $options['selectHostPrototype'],
+				'output' => $options['selectHostPrototypes'],
 				'hostids' => array_column($db_links, 'hostid'),
 				'preservekeys' => true
 			]);
 
 			foreach ($result as &$row) {
-				$row['hostPrototype'] = [];
+				$row['hostPrototypes'] = [];
 			}
 			unset($row);
 
 			foreach ($db_links as $row) {
 				if (array_key_exists($row['hostid'], $host_prototypes)) {
-					$result[$row['groupid']]['hostPrototype'] = $host_prototypes[$row['hostid']];
+					$result[$row['groupid']]['hostPrototypes'][] = $host_prototypes[$row['hostid']];
 				}
 			}
 		}
 
 		// adding group discovery
-		if ($options['selectGroupDiscovery'] !== null) {
-			$groupDiscoveries = API::getApiService()->select('group_discovery', [
-				'output' => $this->outputExtend($options['selectGroupDiscovery'], ['groupid']),
-				'filter' => ['groupid' => $groupIds],
+		if ($options['selectGroupDiscoveries'] !== null) {
+			$output = $options['selectGroupDiscoveries'] === API_OUTPUT_EXTEND
+				? self::GROUP_DISCOVERY_FIELDS
+				: $options['selectGroupDiscoveries'];
+
+			$group_discoveries = API::getApiService()->select('group_discovery', [
+				'output' => $this->outputExtend($output, ['groupid', 'groupdiscoveryid']),
+				'filter' => ['groupid' => $groupids],
 				'preservekeys' => true
 			]);
-			$relationMap = $this->createRelationMap($groupDiscoveries, 'groupid', 'groupid');
+			$relation_map = $this->createRelationMap($group_discoveries, 'groupid', 'groupdiscoveryid');
 
-			$groupDiscoveries = $this->unsetExtraFields($groupDiscoveries, ['groupid'],
-				$options['selectGroupDiscovery']
-			);
-			$result = $relationMap->mapOne($result, $groupDiscoveries, 'groupDiscovery');
+			$group_discoveries = $this->unsetExtraFields($group_discoveries, ['groupid', 'groupdiscoveryid'], $output);
+
+			$result = $relation_map->mapMany($result, $group_discoveries, 'groupDiscoveries');
 		}
 
 		return $result;
