@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -736,7 +731,7 @@ class CSvgGraph extends CSvg {
 
 		$offset_top = 10;
 		$offset_bottom = self::SVG_GRAPH_X_AXIS_HEIGHT;
-		$this->canvas_height = $this->height - $offset_top - $offset_bottom;
+		$this->canvas_height = max(0, $this->height - $offset_top - $offset_bottom);
 		$this->canvas_y = $offset_top;
 
 		// Determine units for left side.
@@ -778,7 +773,7 @@ class CSvgGraph extends CSvg {
 			$this->left_y_max = $this->max_value_left ?: 1;
 		}
 
-		$this->left_y_is_binary = $this->left_y_units === 'B' || $this->left_y_units === 'Bps';
+		$this->left_y_is_binary = isBinaryUnits($this->left_y_units);
 
 		$calc_power = $this->left_y_units === '' || $this->left_y_units[0] !== '!';
 
@@ -795,8 +790,9 @@ class CSvgGraph extends CSvg {
 
 		// Calculate vertical scale parameters for right side.
 
-		if ($this->left_y_min_calculated && $this->left_y_max_calculated) {
-			$rows_min = $rows_max = $result['rows'];
+		if ($this->show_left_y_axis && $this->left_y_min_calculated && $this->left_y_max_calculated) {
+			$rows_min = $result['rows'];
+			$rows_max = $result['rows'];
 		}
 
 		$this->right_y_min_calculated = $this->right_y_min === null;
@@ -809,7 +805,7 @@ class CSvgGraph extends CSvg {
 			$this->right_y_max = $this->max_value_right ?: 1;
 		}
 
-		$this->right_y_is_binary = $this->right_y_units === 'B' || $this->right_y_units === 'Bps';
+		$this->right_y_is_binary = isBinaryUnits($this->right_y_units);
 
 		$calc_power = $this->right_y_units === '' || $this->right_y_units[0] !== '!';
 
@@ -847,7 +843,7 @@ class CSvgGraph extends CSvg {
 			}
 		}
 
-		$this->canvas_width = $this->width - $this->offset_left - $this->offset_right;
+		$this->canvas_width = max(0, $this->width - $this->offset_left - $this->offset_right);
 		$this->canvas_x = $this->offset_left;
 
 		// Calculate vertical zero position.
@@ -1068,22 +1064,14 @@ class CSvgGraph extends CSvg {
 				$bar_stack_x1 = $group_x1;
 
 				foreach ($bar_group as $bar_group_index => $bar_stack) {
-					$sum_positive = 0;
-					$sum_negative = 0;
+					$sum = 0;
 
 					$bar_stack_x2 = $group_x1 + ($bar_group_index + 1) * $metric_width;
 
 					foreach ($bar_stack as [$metric_index, $point_value]) {
-						if ($point_value >= 0) {
-							$value_from = $sum_positive;
-							$value_to = $sum_positive + $point_value;
-							$sum_positive += $point_value;
-						}
-						else {
-							$value_from = $point_value + $point_value;
-							$value_to = $point_value;
-							$sum_negative += $point_value;
-						}
+						$value_from = $sum;
+						$value_to = $sum + $point_value;
+						$sum += $point_value;
 
 						if ($max_value - $min_value == INF) {
 							$bar_y1 = $this->canvas_y + CMathHelper::safeMul([$this->canvas_height,
