@@ -1,39 +1,34 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
 class CFilter extends CDiv {
 
+	// Filter form object name and id attribute.
+	private const FORM_NAME = 'zbx_filter';
+
 	// Filter form object.
 	private $form;
-	// Filter form object name and id attribute.
-	private $name = 'zbx_filter';
+
 	// Visibility of 'Apply', 'Reset' form buttons. Visibility is set to all tabs.
 	private $show_buttons = true;
 
 	/**
-	 * Filter page URL.
-	 *
-	 * @var object
+	 * Filter reset URL.
 	 */
-	private $url;
+	private $reset_url;
 
 	// Array of filter tab headers. Every header is mapped to it content via href(header) and id(content) attribute.
 	protected $headers = [];
@@ -48,6 +43,9 @@ class CFilter extends CDiv {
 	protected $idx = null;
 	protected $idx2 = 0;
 
+	// Time period Div element.
+	private $time_period;
+
 	/**
 	 * List of predefined time ranges.
 	 */
@@ -91,23 +89,26 @@ class CFilter extends CDiv {
 		]
 	];
 
-	public function __construct(CUrl $url) {
+	public function __construct() {
 		parent::__construct();
 
-		$this->url = $url;
-
 		$this
 			->setAttribute('data-accessible', 1)
 			->addClass(ZBX_STYLE_FILTER_SPACE)
 			->setId(uniqid('filter_'));
 
 		$this->form = (new CForm('get'))
-			->cleanItems()
-			->setAttribute('name', $this->name);
+			->setAttribute('name', self::FORM_NAME);
+
+		$this->reset_url = new CUrl();
 	}
 
-	public function getName() {
-		return $this->name;
+	public function setResetUrl(CUrl $url): self {
+		$this->reset_url = (clone $url)
+			->setArgument('filter_rst', 1)
+			->getUrl();
+
+		return $this;
 	}
 
 	/**
@@ -118,8 +119,8 @@ class CFilter extends CDiv {
 	 *
 	 * @return CFilter
 	 */
-	public function addVar($name, $value) {
-		$this->form->addVar($name, $value);
+	public function addVar($name, $value, $id = null) {
+		$this->form->addVar($name, $value, $id);
 
 		return $this;
 	}
@@ -208,11 +209,7 @@ class CFilter extends CDiv {
 						->onClick('javascript: chkbxRange.clearSelectedOnFilterChange();')
 				)
 				->addItem(
-					(new CRedirectButton(_('Reset'),
-						$this->url
-							->setArgument('filter_rst', 1)
-							->getUrl()
-					))
+					(new CRedirectButton(_('Reset'), $this->reset_url))
 						->addClass(ZBX_STYLE_BTN_ALT)
 						->onClick('javascript: chkbxRange.clearSelectedOnFilterChange();')
 				);
@@ -223,7 +220,10 @@ class CFilter extends CDiv {
 		}
 
 		return $this->addTab(
-			(new CLink($header, '#'.$anchor))->addClass(ZBX_STYLE_FILTER_TRIGGER),
+			(new CLink($header, '#'.$anchor))
+				->addClass(ZBX_STYLE_BTN)
+				->addClass(ZBX_ICON_FILTER)
+				->addClass(ZBX_STYLE_FILTER_TRIGGER),
 			(new CDiv($body))
 				->addClass(ZBX_STYLE_FILTER_CONTAINER)
 				->setId($anchor)
@@ -235,21 +235,23 @@ class CFilter extends CDiv {
 	 * - time selector range change buttons: back, zoom out, forward.
 	 * - time selector range change form with predefined ranges.
 	 *
-	 * @param string $from    Start date. (can be in relative time format, example: now-1w)
-	 * @param string $to      End date. (can be in relative time format, example: now-1w)
-	 * @param bool   $visible Either to make time selector visible or hidden.
-	 * @param string $format  Date and time format used in CDateSelector.
+	 * @param string $from        Start date. (can be in relative time format, example: now-1w)
+	 * @param string $to          End date. (can be in relative time format, example: now-1w)
+	 * @param bool   $visible     Either to make time selector visible or hidden.
+	 * @param string $profileidx  Profile key.
+	 * @param string $format      Date and time format used in CDateSelector.
 	 *
 	 * @return CFilter
 	 */
-	public function addTimeSelector($from, $to, $visible = true, $format = ZBX_FULL_DATE_TIME) {
+	public function addTimeSelector(string $from, string $to, bool $visible = true, string $profileidx = '',
+			string $format = ZBX_FULL_DATE_TIME): CFilter {
 		$header = relativeDateToText($from, $to);
 
 		if ($visible) {
 			$this->addTab(new CDiv([
-				(new CSimpleButton())->addClass(ZBX_STYLE_BTN_TIME_LEFT),
-				(new CSimpleButton(_('Zoom out')))->addClass(ZBX_STYLE_BTN_TIME_OUT),
-				(new CSimpleButton())->addClass(ZBX_STYLE_BTN_TIME_RIGHT)
+				(new CButtonIcon(ZBX_ICON_CHEVRON_LEFT))->addClass('js-btn-time-left'),
+				(new CSimpleButton(_('Zoom out')))->addClass(ZBX_STYLE_BTN_TIME_ZOOMOUT),
+				(new CButtonIcon(ZBX_ICON_CHEVRON_RIGHT))->addClass('js-btn-time-right')
 			]), null);
 
 			$predefined_ranges = [];
@@ -275,35 +277,47 @@ class CFilter extends CDiv {
 			$anchor = 'tab_'.count($this->tabs);
 
 			$this->addTab(
-				(new CLink($header, '#'.$anchor))->addClass(ZBX_STYLE_BTN_TIME),
-				(new CDiv([
-					(new CDiv([
-						new CList([
-							new CLabel(_('From'), 'from'),
-							(new CDateSelector('from', $from))->setDateFormat($format)
-						]),
-						(new CList([(new CListItem(''))->addClass(ZBX_STYLE_RED)]))
-							->setAttribute('data-error-for', 'from')
-							->addClass(ZBX_STYLE_TIME_INPUT_ERROR)
-							->addStyle('display: none'),
-						new CList([
-							new CLabel(_('To'), 'to'),
-							(new CDateSelector('to', $to))->setDateFormat($format)
-						]),
-						(new CList([(new CListItem(''))->addClass(ZBX_STYLE_RED)]))
-							->setAttribute('data-error-for', 'to')
-							->addClass(ZBX_STYLE_TIME_INPUT_ERROR)
-							->addStyle('display: none'),
-						new CList([
-							new CButton('apply', _('Apply'))
-						])
-					]))->addClass(ZBX_STYLE_TIME_INPUT),
-					(new CDiv($predefined_ranges))->addClass(ZBX_STYLE_TIME_QUICK_RANGE)
-				]))
-					->addClass(ZBX_STYLE_FILTER_CONTAINER)
-					->addClass(ZBX_STYLE_TIME_SELECTION_CONTAINER)
-					->setId($anchor)
+				(new CLink($header, '#'.$anchor))
+					->addClass(ZBX_STYLE_BTN)
+					->addClass(ZBX_ICON_CLOCK)
+					->addClass(ZBX_STYLE_BTN_TIME),
+				new CDiv()
 			);
+
+			$this->time_period = (new CDiv([
+				(new CDiv([
+					new CList([
+						new CLabel(_('From'), 'from'),
+						(new CDateSelector('from', $from))->setDateFormat($format)
+					]),
+					(new CList([(new CListItem(''))->addClass(ZBX_STYLE_RED)]))
+						->setAttribute('data-error-for', 'from')
+						->addClass(ZBX_STYLE_TIME_INPUT_ERROR)
+						->addStyle('display: none'),
+					new CList([
+						new CLabel(_('To'), 'to'),
+						(new CDateSelector('to', $to))->setDateFormat($format)
+					]),
+					(new CList([(new CListItem(''))->addClass(ZBX_STYLE_RED)]))
+						->setAttribute('data-error-for', 'to')
+						->addClass(ZBX_STYLE_TIME_INPUT_ERROR)
+						->addStyle('display: none'),
+					new CList([
+						new CButton('apply', _('Apply'))
+					])
+				]))->addClass(ZBX_STYLE_TIME_INPUT),
+				(new CDiv($predefined_ranges))->addClass(ZBX_STYLE_TIME_QUICK_RANGE)
+			]))
+				->addClass(ZBX_STYLE_FILTER_CONTAINER)
+				->addClass(ZBX_STYLE_TIME_SELECTION_CONTAINER)
+				->setId($anchor);
+
+			if ($profileidx !== '') {
+				$this->form->addItem((new CVar('from',
+					CProfile::get($profileidx.'.from', 'now-'.CSettingsHelper::get(CSettingsHelper::PERIOD_DEFAULT))
+				))->removeId());
+				$this->form->addItem((new CVar('to', CProfile::get($profileidx.'.to', 'now')))->removeId());
+			}
 		}
 		else {
 			$this
@@ -317,11 +331,22 @@ class CFilter extends CDiv {
 		return $this;
 	}
 
+	/**
+	 * Prevent modifying history URL with time selector parameters.
+	 *
+	 * @return CFilter
+	 */
+	public function preventHistoryUpdates(): CFilter {
+		$this->setAttribute('data-prevent-history-updates', 1);
+
+		return $this;
+	}
+
 	/**
 	 * Add tab.
 	 *
-	 * @param string|CTag $header    Tab header title string or CTag container.
-	 * @param array       $body      Array of body elements.
+	 * @param string|CTag $header  Tab header title string or CTag container.
+	 * @param array|CTag  $body    Array of body elements.
 	 *
 	 * @return CFilter
 	 */
@@ -395,6 +420,7 @@ class CFilter extends CDiv {
 		}
 
 		$this->addItem($this->form);
+		$this->addItem($this->time_period);
 
 		return parent::toString($destroy).($headers_cnt ? get_js($this->getJS()) : '');
 	}
