@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -419,32 +414,32 @@ class CNewValidator {
 	 * @return bool
 	 */
 	private function check_db_value($field_schema, &$value, $flags) {
-		switch ($field_schema['type']) {
-			case DB::FIELD_TYPE_ID:
-				return self::is_id($value);
-
-			case DB::FIELD_TYPE_INT:
-				return self::is_int32($value);
-
-			case DB::FIELD_TYPE_CHAR:
-				if ($flags & P_CRLF) {
-					$value = CRLFtoLF($value);
-				}
-
-				return (mb_strlen($value) <= $field_schema['length']);
-
-			case DB::FIELD_TYPE_NCLOB:
-			case DB::FIELD_TYPE_TEXT:
-				if ($flags & P_CRLF) {
-					$value = CRLFtoLF($value);
-				}
-
-				// TODO: check length
-				return true;
-
-			default:
-				return false;
+		if ($field_schema['type'] & DB::FIELD_TYPE_ID) {
+			return self::is_id($value);
 		}
+
+		if ($field_schema['type'] & DB::FIELD_TYPE_INT) {
+			return self::is_int32($value);
+		}
+
+		if ($field_schema['type'] & DB::FIELD_TYPE_CHAR) {
+			if ($flags & P_CRLF) {
+				$value = CRLFtoLF($value);
+			}
+
+			return (mb_strlen($value) <= $field_schema['length']);
+		}
+
+		if ($field_schema['type'] & (DB::FIELD_TYPE_NCLOB | DB::FIELD_TYPE_TEXT)) {
+			if ($flags & P_CRLF) {
+				$value = CRLFtoLF($value);
+			}
+
+			// TODO: check length
+			return true;
+		}
+
+		return false;
 	}
 
 	private function is_array_id(array $values) {
