@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -46,17 +41,7 @@ $fields = [
 	'to' =>					[T_ZBX_RANGE_TIME,	O_OPT,	P_SYS,				null,	null]
 ];
 check_fields($fields);
-
-if (hasRequest('from') || hasRequest('to')) {
-	validateTimeSelectorPeriod(
-		hasRequest('from') ? getRequest('from') : null,
-		hasRequest('to') ? getRequest('to') : null
-	);
-}
-
-$timeselector_from = getRequest('from', CProfile::get('web.avail_report.filter.from',
-	'now-'.CSettingsHelper::get(CSettingsHelper::PERIOD_DEFAULT)));
-$timeselector_to = getRequest('to', CProfile::get('web.avail_report.filter.to', 'now'));
+validateTimeSelectorPeriod(getRequest('from'), getRequest('to'));
 
 $report_mode = getRequest('mode', CProfile::get('web.avail_report.mode', AVAILABILITY_REPORT_BY_HOST));
 CProfile::update('web.avail_report.mode', $report_mode, PROFILE_TYPE_INT);
@@ -102,8 +87,6 @@ if (hasRequest('filter_set')) {
 		CProfile::update($key_prefix.'.hostgroupid', getRequest('hostgroupid', 0), PROFILE_TYPE_ID);
 	}
 	else {
-		CProfile::update('web.avail_report.filter.from', $timeselector_from, PROFILE_TYPE_STR);
-		CProfile::update('web.avail_report.filter.to', $timeselector_to, PROFILE_TYPE_STR);
 		CProfile::updateArray($key_prefix.'.groupids', getRequest('filter_groups', []), PROFILE_TYPE_ID);
 		CProfile::updateArray($key_prefix.'.hostids', getRequest('filter_hostids', []), PROFILE_TYPE_ID);
 	}
@@ -140,6 +123,15 @@ $data['filter'] = ($report_mode == AVAILABILITY_REPORT_BY_TEMPLATE)
 		'hostids' => CProfile::getArray($key_prefix.'.hostids', getRequest('filter_hostids', []))
 	];
 
+// Get time selector filter values.
+$timeselector_options = [
+	'profileIdx' => 'web.avail_report.filter',
+	'profileIdx2' => 0,
+	'from' => getRequest('from'),
+	'to' => getRequest('to')
+];
+updateTimeSelectorPeriod($timeselector_options);
+
 /*
  * Header
  */
@@ -207,12 +199,7 @@ else {
 	 * Filter
 	 */
 	$data['filter'] += [
-		'timeline' => getTimeSelectorPeriod([
-			'profileIdx' => 'web.avail_report.filter',
-			'profileIdx2' => 0,
-			'from' => $timeselector_from,
-			'to' => $timeselector_to
-		]),
+		'timeline' => getTimeSelectorPeriod($timeselector_options),
 		'active_tab' => CProfile::get('web.avail_report.filter.active', 1)
 	];
 
@@ -252,7 +239,7 @@ else {
 		$select_filter_hostid = (new CSelect('filter_templateid'))
 			->setValue($data['filter']['hostids'])
 			->setFocusableElementId('filter-templateid')
-			->addOption(new CSelectOption(0, _('all')));
+			->addOption(new CSelectOption(0, _('All')));
 
 		foreach ($templates as $templateid => $template) {
 			$select_filter_hostid->addOption(new CSelectOption($templateid, $template['name']));
@@ -295,7 +282,7 @@ else {
 		$select_tpl_triggerid = (new CSelect('tpl_triggerid'))
 			->setValue($data['filter']['tpl_triggerid'])
 			->setFocusableElementId('tpl-triggerid')
-			->addOption(new CSelectOption(0, _('all')));
+			->addOption(new CSelectOption(0, _('All')));
 
 		$tpl_triggerids = [];
 
@@ -322,7 +309,7 @@ else {
 		$select_hostgroupid = (new CSelect('hostgroupid'))
 			->setValue($data['filter']['hostgroupid'])
 			->setFocusableElementId('hostgroupid')
-			->addOption(new CSelectOption(0, _('all')));
+			->addOption(new CSelectOption(0, _('All')));
 
 		foreach ($host_groups as $groupid => $group) {
 			$select_hostgroupid->addOption(new CSelectOption($groupid, $group['name']));
@@ -379,7 +366,7 @@ else {
 			->setAttribute('autofocus', 'autofocus')
 			->setValue($data['filter']['groups'])
 			->setFocusableElementId('filter-groups')
-			->addOption(new CSelectOption(0, _('all')));
+			->addOption(new CSelectOption(0, _('All')));
 
 		foreach ($groups as $groupid => $group) {
 			$select_filter_groupid->addOption(new CSelectOption($groupid, $group['name']));
@@ -406,18 +393,6 @@ else {
 	}
 	// Report by host.
 	else {
-		// Sanitize $data['filter']['groups'] and prepare "Host groups" filter field.
-		$data['filter']['groups'] = $data['filter']['groups']
-			? CArrayHelper::renameObjectsKeys(API::HostGroup()->get([
-				'output' => ['groupid', 'name'],
-				'groupids' => $data['filter']['groups'],
-				'with_monitored_hosts' => true,
-				'preservekeys' => true
-			]), ['groupid' => 'id'])
-			: [];
-
-		CArrayHelper::sort($data['filter']['groups'], ['name']);
-
 		// Sanitize $data['filter']['hostids'] and prepare "Hosts" filter field.
 		$data['filter']['hostids'] = $data['filter']['hostids']
 			? CArrayHelper::renameObjectsKeys(API::Host()->get([
@@ -431,14 +406,16 @@ else {
 
 		CArrayHelper::sort($data['filter']['hostids'], ['name']);
 
-		// Select monitored host triggers, derived from templates and belonging to the requested groups.
-		$groups = enrichParentGroups($data['filter']['groups']);
+		$groupids = getSubGroups($data['filter']['groups'], $data['filter']['groups'], 'host',
+			['with_monitored_hosts' => true]
+		);
+		CArrayHelper::sort($data['filter']['groups'], ['name']);
 
 		$limit = CSettingsHelper::get(CSettingsHelper::SEARCH_LIMIT) + 1;
 		$triggers = API::Trigger()->get([
 			'output' => ['triggerid', 'description', 'expression', 'value'],
 			'selectHosts' => ['name'],
-			'groupids' => $groups ? array_keys($groups) : null,
+			'groupids' => $groupids ? $groupids : null,
 			'hostids' => $data['filter']['hostids'] ? array_keys($data['filter']['hostids']) : null,
 			'expandDescription' => true,
 			'monitored' => true,
@@ -509,8 +486,6 @@ else {
 	/*
 	 * Triggers
 	 */
-	$triggerTable = (new CTableInfo())->setHeader([_('Host'), _('Name'), _('Problems'), _('Ok'), _('Graph')]);
-
 	CArrayHelper::sort($triggers, ['host_name', 'description']);
 
 	// pager
@@ -519,6 +494,10 @@ else {
 	$paging = CPagerHelper::paginate($page_num, $triggers, ZBX_SORT_UP, new CUrl('report2.php'));
 	$allowed_ui_problems = CWebUser::checkAccess(CRoleHelper::UI_MONITORING_PROBLEMS);
 
+	$triggerTable = (new CTableInfo())
+		->setHeader([_('Host'), _('Name'), _('Problems'), _('Ok'), _('Graph')])
+		->setPageNavigation($paging);
+
 	foreach ($triggers as $trigger) {
 		$availability = calculateAvailability($trigger['triggerid'], $data['filter']['timeline']['from_ts'],
 			$data['filter']['timeline']['to_ts']
@@ -557,7 +536,7 @@ else {
 	zbx_add_post_js('timeControl.processObjects();');
 
 	$html_page
-		->addItem([$triggerTable, $paging])
+		->addItem($triggerTable)
 		->show();
 }
 
